/*
  Stepper_Axlr8_i.h - Stepper library with acceleration / deceleration 
  with interupt for Wiring/Arduino 
  - Version 1.0
 */

// ensure this library description is only included once
#ifndef Stepper_Aclr8_i_h
#define Stepper_Aclr8_i_h

// library interface description
class Stepper_Aclr8_i {
  public:
	// constructor: 4 wire stepper motors only
	Stepper_Aclr8_i(int number_of_steps, int motor_pin_1, \
		int motor_pin_2, int motor_pin_3, int motor_pin_4);

	// min speed setter method
    void setMinSpeed(long minSpeed);

    // max speed setter method
    void setMaxSpeed(long maxSpeed);

    // accelerator method
	void setAcc(double Accel);

	// define interupt pins method:
	void setIpins(int firePin, int readPin);

    // define method and global variable to hold data of step address
	void setToDoAddress(int *StepsAddress);
	int *gStepAdd;

	// step method
    void step(int steps_to_move);

	// return the version if asked
	int version(void);

  private:
    // setup the motor
    void stepMotor(int thisStep);

	// Direction of rotation
	int direction;        
    // Speed in RPMs
	int speed;          
    // delay between steps, in ms, based on speed
    double step_delay;    
	// total number of steps this motor can take
	int number_of_steps;      
    // delay at 1 rev per minute
    double delay_1revpermin;
	// which step the motor is on
	int step_number;        
	//steps left
	int steps_left;    
	// which step number of steps to take
	int steps_no;

	// total steps for motor
	int total_steps_left;

	// motor pin numbers:
    int motor_pin_1;
    int motor_pin_2;
    int motor_pin_3;
    int motor_pin_4;
    
	// time stamp in ms of when the last step was taken
	long last_step_time;      

	// acceleration
	long motorSpeed;
	long motorMinSpeed;
	long motorMaxSpeed;
	long motorAccSteps;
	double motorAccelVal;

	// interupt pins
	int firePin;
	int readPin;
};

#endif